# UI/UX Feedback

**ID:** Feedback-20260129-160635
**URL:** idea://003. Feature-Toolbox Design/mockups/stage-toolbox-modal-v2.html
**Date:** 2026-01-29 16:06:43

## Selected Elements

- `{'selector': 'div.accordion-title', 'parents': ['div.accordion', 'div.accordion-item.expanded', 'div.accordion-header', 'div.accordion-info']}`

## Feedback

make the size bigger

## Screenshot

![Screenshot](./page-screenshot.png)
